# ai-assistant
Small terminal AI CLI pal for generating content.

## Installation

Install `aiclipal`: [`pip install -U aiclipal`](https://pypi.org/project/aiclipal/)

## Usage
Just run from the command line. By default you need to have the `AI_CLI_PAL_OPENAI_API_KEY`
environment variable exported to the command line containing your API key for OpenAI.

Then run `aiclipal -h` to get more information

## Copyright
Created by Grzegorz Grzęda. Distributed under MIT license